---
name: Parameters
about: Make a suggestion for a change of input parameters or a new output to dpgen.
  If this doesn’t work right, [choose a different type]( https://github.com/deepmodeling/dpgen/issues/new/choose).
title: "[Parameters] _Replace With Suitable Title_"
labels: documentation, enhancement
assignees: ''

---

**Summary**

<!--Please provide a clear and concise description of what your request is.-->

**Summary**

<!--Please provide a brief and concise description of the suggested feature or change-->

**Detailed Description**

<!--Please explain how you would like to see dpgen enhanced. Specify your material system, and exactly what behaviors or properties you are looking for, or what specific problems this will solve. If possible, provide references to relevant background information like publications or web pages, and whether you are planning to implement the enhancement yourself or would like to participate in the implementation.-->

**Further Information, Files, and Links**

<!--Put any additional information here, attach relevant text or image files and URLs to external sites, e.g. relevant publications-->
